@@ -43,11 +43,14 @@ class FunctionCallChecker(BaseChecker):
             if isinstance(statement, astroid.nodes.Expr):
                 if is_line_split(statement.value):
                     args_length = compute_arguments_length(statement.value.args)
-                    total_length = (
-                        len(statement.value.func.name)
-                        + statement.col_offset
-                        + args_length
-                    )
+                    try:
+                        total_length = (
+                            len(statement.value.func.name)
+                            + statement.col_offset
+                            + args_length
+                        )
+                    except AttributeError:
+                        pass
                     if total_length <= 120:
                         self.add_message("unnecessarily-split-call", node=node)
         self._function_stack.append([])
