@@ -61,12 +61,15 @@ def module_contains_display(expression):
     except AttributeError:
         contains_display_attr = False
     contains_display_func = False
-    for arg in expression.value.args:
-        contains_display_func = (
-            isinstance(arg.parent, astroid.nodes.Call)
-            and hasattr(arg.parent.func, "name")
-            and arg.parent.func.name == "display"
-        )
+    if hasattr(expression.value, "args"):
+        for arg in expression.value.args:
+            contains_display_func = (
+                isinstance(arg.parent, astroid.nodes.Call)
+                and hasattr(arg.parent.func, "name")
+                and arg.parent.func.name == "display"
+            )
+    else:
+        contains_display_func = False
     return (
         contains_func_attribute and contains_attrname and contains_display_attr
     ) or (contains_func_attribute and contains_display_func)
@@ -86,26 +89,35 @@ def module_contains_show(expression):
     except AttributeError:
         contains_show_attr = False
     contains_show_func = False
-    for arg in expression.value.args:
-        contains_show_func = (
-            isinstance(arg.parent, astroid.nodes.Call)
-            and hasattr(arg.parent.func, "name")
-            and arg.parent.func.name == "show"
-        )
+    if hasattr(expression.value, "args"):
+        for arg in expression.value.args:
+            contains_show_func = (
+                isinstance(arg.parent, astroid.nodes.Call)
+                and hasattr(arg.parent.func, "name")
+                and arg.parent.func.name == "show"
+            )
+    else:
+        contains_show_func = False
     return (contains_func_attribute and contains_attrname and contains_show_attr) or (
         contains_func_attribute and contains_show_func
     )
 
 
 def module_contains_print(expression):
-    contains_func_attribute = hasattr(expression.value, "func")
+    try:
+        contains_func_attribute = hasattr(expression.value, "func")
+    except AttributeError:
+        contains_func_attribute = False
     contains_print_func = False
-    for arg in expression.value.args:
-        contains_print_func = (
-            isinstance(arg.parent, astroid.nodes.Call)
-            and hasattr(arg.parent.func, "name")
-            and arg.parent.func.name == "print"
-        )
+    if hasattr(expression.value, "args"):
+        for arg in expression.value.args:
+            contains_print_func = (
+                isinstance(arg.parent, astroid.nodes.Call)
+                and hasattr(arg.parent.func, "name")
+                and arg.parent.func.name == "print"
+            )
+    else:
+        contains_print_func = False
     return contains_func_attribute and contains_print_func
 
 
